#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-pragmas-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-pragmas-plugin-2.3.0.0-5VvUisXn8LkUH1ejhKh58
key:                  hls-pragmas-plugin-2.3.0.0-5VvUisXn8LkUH1ejhKh58
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Pragmas plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  014abc1816bd17418cbdf9e061e5416a
exposed:              True
exposed-modules:      Ide.Plugin.Pragmas
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-pragmas-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-pragmas-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-pragmas-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-pragmas-plugin
hs-libraries:         HShls-pragmas-plugin-2.3.0.0-5VvUisXn8LkUH1ejhKh58
depends:
    base-4.18.2.1 containers-0.6.7 extra-1.7.16-JqlpUalRpf3DrrxiVQYUyX
    fuzzy-0.1.1.0-8M5VYoeVxJQ8mcvkYSN7gf ghc-9.6.6
    ghcide-2.3.0.0-F8jFt2FEiLgKgaY5bwOadD
    hls-plugin-api-2.3.0.0-JvSLuDAqDRP3LXV4joMX1
    lens-5.3.5-ApAD4D8hy7K2t3Q7L3bBvG
    lsp-2.2.0.0-IKZ4Mpp9MNAHQA77xxW2p1 text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp

haddock-interfaces:
    /usr/share/doc/haskell-hls-pragmas-plugin/html/hls-pragmas-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-pragmas-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

